#ifndef KYSEC_MEMDB_WHLIST_H__
#define KYSEC_MEMDB_WHLIST_H__

#include <time.h>

struct db_object;
struct object_list;

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 创建kysec白名单内存数据库
 * 
 * @return int 0 成功，其他， 失败
 */
int kysec_memdb_whlist_create();

/**
 * @brief 删除kysec白名单内存数据库
 * 
 * @return int 0 成功， 其他  失败
 */
int kysec_memdb_whlist_delete();


/*
 * 执行控制白名单添加接口
 * 参数：
 *      obj 需要添加执行控制白名单记录的基础数据
 * 返回值：
 *      0： 添加成功
 *      其他: 添加失败
 */
int kysec_memdb_whlist_exectl_add(struct db_object obj);

/*
 * 执行控制白名单记录status字段更新
 * 参数：
 *      fpath 文件路径
 *      status 更新状态
 * 返回值：
 *      0： 更新成功
 *      其他: 更新失败
 */
int kysec_memdb_whlist_exectl_update_status(const char *fpath, int status);

/*
 * 执行控制白名单删除接口
 * 参数：
 *      fpath：需要删除文件路径；
 * 返回值：
 *      0： 删除成功
 *      其他： 删除失败
 */
int kysec_memdb_whlist_exectl_remove(const char* fpath);

/**
 * @brief 根据过滤参数获取白名单列表
 * 
 * @param fpath 文件路径，过滤参数，为空时不按该参数进行查询
 * @param file_type 文件类型，过滤参数，为空时不按该参数进行查询
 * @param exectl_label 文件标记，过滤参数，为空时不按该参数进行查询
 * @param hash 文件哈希，过滤参数，为空时不按该参数进行查询
 * @param status 记录状态值，过滤参数，为-1时不按该参数进行查询
 * @param objects 传出参数，记录列表
 * @return int 0：获取成功
 *          其他： 获取失败
 */
int kysec_memdb_whlist_exectl_load(const char *fpath, const char *file_type, const char *exectl_label, const char *hash, const int status,  struct object_list *objects);

/**
 * @brief 加载特殊标记执行控制白名单
 * 
 * @param objects 传出参数，记录列表
 * @return int 0：获取成功
 *          其他： 获取失败
 */
int kysec_memdb_whlist_exectl_load_special(struct object_list *objects);

/**
 * @brief 根据过滤参数获取白名单列表
 * 
 * @param fpath 文件路径，过滤参数，为空时不按该参数进行查询
 * @param file_type 文件类型，过滤参数，为空时不按该参数进行查询
 * @param exectl_label 文件标记，过滤参数，为空时不按该参数进行查询
 * @param hash_value 文件哈希，过滤参数，为空时不按该参数进行查询
 * @param status 记录状态值，过滤参数，为-1时不按该参数进行查询
 * @param objects 传出参数，记录列表
 * @return int 0：获取成功
 *          其他： 获取失败
 */
int kysec_memdb_whlist_exectl_load_by_daemon(const char *fpath, const char *file_type, const char *exectl_label, const char *hash_value, const int status,  struct object_list *objects);

/**
 * @brief 获取指定更新时间之后更新的记录
 * 
 * @param time 指定时间 
 * @param objects 传出参数，记录列表
 * @return int 0：获取成功
 *          其他： 获取失败
 */
int kysec_memdb_whlist_exectl_load_after_time(time_t time, struct object_list *objects);

/**
 * @brief 获取最近一次同步更新时间
 * 
 * @return int 最近一次更新时间， 0 表示无记录
 */
int kysec_memdb_whlist_exectl_get_lasted_sync_time();

/**
 * @brief 更新最近一次同步更新时间
 * 
 * @param time 同步更新时间
 * @return int 0： 成功
 *          其他： 失败
 */
int kysec_memdb_whlist_exectl_update_lasted_sync_time(time_t time);

/**
 * @brief 计算文件md5值
 * 
 * @param fpath 文件路径
 * @return char* 文件哈希， 失败时返回空
 */
char *kysec_memdb_whlist_calc_md5_for_file(const char *fpath);


#ifdef __cplusplus
}
#endif

#endif


